.. currentmodule:: pyhomogenize

#############
API reference
#############

This page provides an auto-generated summary of the pyhomogenize API.

Pyhomogenize time creating and manipulating classes
===================================================

.. toctree::
   :maxdepth: 2

   api_basics

.. toctree::
   :maxdepth: 2

   api_netcdf_basics

.. toctree::
   :maxdepth: 2

   api_time_control

.. toctree::
   :maxdepth: 2

   api_time_compare

Methods for creating, reading and manipulating CF time axes
===========================================================

.. toctree::
   :maxdepth: 2

   api_methods

pyhomogenize's attributes
=========================

.. toctree::
   :maxdepth: 2

   api_attributes
